==> 0.4.0.tar.gz: lib/http/dio_utils.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:cookie_jar/cookie_jar.dart';
import 'package:dio/adapter.dart';
import 'package:dio/dio.dart';
import 'package:dio_cookie_manager/dio_cookie_manager.dart';
import 'package:dio_retry_fixed/dio_retry_fixed.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:path_provider/path_provider.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';
import 'package:worker_manager/worker_manager.dart';
import 'exception/http_error.dart';
import 'http_data.dart';


Future<HttpData> _request(_DioConfig dioConfig, _RequestConfig requestConfig) async{

  Dio dio = Dio(BaseOptions(
      contentType: Headers.formUrlEncodedContentType,
      connectTimeout: 5 * 1000,
      receiveTimeout: 30 * 1000
  ));

  dio.options = dio.options.merge(
      baseUrl: dioConfig.baseUrl??dio.options.baseUrl,
      connectTimeout: dioConfig.connectTimeout??dio.options.connectTimeout,
      receiveTimeout: dioConfig.receiveTimeout??dio.options.receiveTimeout,
      headers: Map.from(dio.options.headers)..addAll(dioConfig.headers??{}),
      responseType: dioConfig.responseType??dio.options.responseType,
      extra: Map.from(dio.options.extra)..addAll(dioConfig.extra??{}),
      contentType: dioConfig.contentType??dio.options.contentType,
      validateStatus: dioConfig.validateStatus??dio.options.validateStatus,
      followRedirects: dioConfig.followRedirects??dio.options.followRedirects
  );


  if (isNotEmpty(dioConfig.interceptors)) {
    dio.interceptors..addAll(dioConfig.interceptors);
  }



  if(dioConfig.openLog && isInDebugMode){
    dio.interceptors.add(PrettyDioLogger(
        requestHeader: true,
        requestBody: true,
        responseBody: true,
        responseHeader: false,
        error: true,
        compact: true,
        maxWidth: 90)
    );
  }


  if (dioConfig.retry != 0) {
    dio.interceptors.add(RetryInterceptor(
        dio: dio,
        options: RetryOptions(
          retries: dioConfig.retry, // Number of retries before a failure
          retryInterval: const Duration(seconds: 1), // Interval between each retry
        )
    ));
  }



  if(dioConfig.enableAutoCookie){
    getTemporaryDirectory().then((value){
      dio.interceptors.add(CookieManager(PersistCookieJar(dir: value.path)));
    });
  }


  ///-----------------------------------------证书相关信息-------------------------------------
  if (dio != null) {
    (dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
      client.badCertificateCallback = (X509Certificate cert, String host, int port) {
        if (isNotEmpty(dioConfig.pem)) {
          if (cert.pem == dioConfig.pem) {
            // 证书一致，则放行
            return true;
          }else{
            return false;
          }
        }else{
          return true;
        }
      };
    };
    if (isNotEmpty(dioConfig.pKCSPath) && isNotEmpty(dioConfig.pKCSPwd)) {
      (dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
        SecurityContext sc = new SecurityContext();
        //file为证书路径
        sc.setTrustedCertificates(dioConfig.pKCSPath, password: dioConfig.pKCSPwd);
        HttpClient httpClient = new HttpClient(context: sc);
        return httpClient;
      };
    }
  }

  Response response;
  String _code;
  String _msg;
  var _resultData;
  HttpData _httpData;

  Options requestOptions = Options();

  if (requestConfig.isFormData) {
    requestConfig.data = FormData.fromMap(requestConfig.data);
  }


  requestOptions.method = requestConfig.method;

  try{
    if (requestConfig.method == Method.get) {
      response = await dio.request(
          requestConfig.path,
          queryParameters: requestConfig.data,
          options:requestOptions,
          cancelToken: requestConfig.cancelToken
      );
    }else{
      response = await dio.request(
          requestConfig.path,
          data: requestConfig.data,
          options: requestOptions,
          cancelToken: requestConfig.cancelToken
      );
    }

    if (isNotEmpty(isNotEmpty(response.data))) {
      if (response.data is List) {
        _resultData = response.data;
        _code = dioConfig.successCode;
      }else{
        Map<String, dynamic> resJson;
        if(response.data is Map){
          resJson = response.data;
        }else{
          resJson = json.decode(response.data);
        }
        _code = resJson[requestConfig.codeKey??dioConfig.codeKey].toString();
        _msg = resJson[requestConfig.msgKey??dioConfig.msgKey];


        if(_code != (requestConfig.successCode??dioConfig.successCode)){
          return HttpData(
            code: _code,
            msg: _msg,
            httpError: HttpError(_code.toString(), _msg)
          );
        }
        _resultData = resJson[requestConfig.dataKey??dioConfig.dataKey];
      }

      _httpData = HttpData(
          code: _code,
          msg: _msg,
          data: _resultData
      );

      return _httpData;
    }else{
      ///response.data为空
      return HttpData(
          code: _code,
          msg: _msg,
          httpError: HttpError(response.statusCode.toString(), response.statusMessage)
      );
    }
  }catch(e){
    return HttpData(
        code: _code,
        msg: _msg,
        httpError: HttpError(HttpError.UNKNOWN, e.toString())
    );
  }
}


/// 请求方法.
class Method {
  static final String get = "GET";
  static final String post = "POST";
  static final String put = "PUT";
  static final String head = "HEAD";
  static final String delete = "DELETE";
  static final String patch = "PATCH";
}




class DioUtils {

  //服务器路径

  static DioUtils _instance = DioUtils._internal();

  Dio _dio;

  factory DioUtils() => _instance;

  _DioConfig _dioConfig;

  Function _onError;

  Function _onFinish;

  Function _onStart;

  ValidateHttpData _validateHttpData;


  ///-----------------------------------------工具类初始化设置-------------------------------------

  DioUtils._internal();

  ///初始化公共属性
  ///
  /// [baseUrl] 地址前缀
  /// [connectTimeout] 连接超时赶时间
  /// [receiveTimeout] 接收超时赶时间
  /// [interceptors] 基础拦截器
  void init({String baseUrl,
    int connectTimeout,
    int receiveTimeout,
    String pem,
    String pKCSPath,
    String pKCSPwd,
    String codeKey,
    String msgKey,
    String dataKey,
    String successCode,
    String responseType,
    bool openLog = true,
    int retry = 3,
    Map<String, dynamic> headers,
    Map<String, dynamic> extra,
    String contentType,
    ValidateStatus validateStatus,
    bool followRedirects,
    Function onError,
    Function onFinish,
    Function onStart,
    ValidateHttpData validateHttpData,
    bool enableAutoCookie = false,
    List<Interceptor> interceptors}) {

    this._onStart = onStart;
    this._onError = onError;
    this._onFinish = onFinish;

    _dioConfig = _DioConfig(
        baseUrl: baseUrl,
        connectTimeout: connectTimeout,
        receiveTimeout: receiveTimeout,
        pem: pem,
        pKCSPath: pKCSPath,
        pKCSPwd: pKCSPwd,
        codeKey: codeKey??'code',
        msgKey: msgKey??'msg',
        dataKey: dataKey??'data',
        successCode: successCode??'0',
        responseType: responseType,
        openLog: openLog??true,
        retry: retry??3,
        headers: headers??{},
        extra: extra??{},
        contentType: contentType,
        validateStatus: validateStatus,
        followRedirects: followRedirects,
        enableAutoCookie: enableAutoCookie,
        interceptors: interceptors??[],
    );

  }


  ///-----------------------------------------请求方法封装-------------------------------------

  // ignore: missing_return
  Future<HttpData> request(
      String method,
      String path, {
        String cacheKey,
        bool isFormData = false,
        bool publicMethod = true,
        data,
        Options options,
        CancelToken cancelToken,
        Function onStart,
        Function onError,
        Function onFinish,
        ValidateHttpData validateHttpData,
        String successCode,
        String codeKey,
        String msgKey,
        String dataKey}) async{


    HttpData _httpData;

    bool useFinish = false;

    try{
      if (onStart != null){
        onStart();
      }else if(this._onStart != null){
        if (publicMethod) {
          this._onStart();
        }
      }



      _httpData = await Executor().execute(arg1: _dioConfig, arg2: _RequestConfig(
          method: method,
          path: path,
          isFormData: isFormData,
          data: data,
          successCode: successCode,
          codeKey: codeKey,
          msgKey: msgKey,
          dataKey: dataKey
      ), fun2: _request);

      if (isNotEmpty(_httpData.httpError)) {
        throw _httpData.httpError;
      }

      if (isNotEmpty(validateHttpData)) {
        validateHttpData(_httpData);
      }else if(isNotEmpty(_validateHttpData)){
        _validateHttpData(_httpData);
      }

      if(!useFinish){
        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(this._onFinish != null){
          this._onFinish();
        }
        useFinish = true;
      }

      return _httpData;
    }catch(e, s){
      var error;
      if (e is DioError) {
        error = HttpError.dioError(e, s);
      }else{
        error = e;
      }

      if(onError != null){
        onError.call(error);
      }else if (this._onError != null) {
        if (publicMethod) {
          this._onError.call(error);
        }
      }
      if(!useFinish){
        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(this._onFinish != null){
          this._onFinish();
        }
        useFinish = true;
      }
      return Future.error(error);
    }
  }




  void fileUpload(String path, Map<String, dynamic> map, {Function onSendProgress, Function onStart, Function onError, Function onFinish}) async{
    FormData formData = FormData.fromMap(map);
    Response response;
    try{
      response = await _dio.post(
          path,
          data: formData,
          onSendProgress: (int sent, int total){
            if (onSendProgress != null) {
              onSendProgress.call(sent, total);
            }
          }
      );
    }on DioError catch(e, s){
      throw HttpError.dioError(e, s);
    }catch(e){
      if (e is HttpError) {
        if(onError != null){
          onError.call(e);
        }else if (this._onError != null) {
          this._onError.call(e);
        }

        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(this._onFinish != null){
          this._onFinish();
        }
      }
    }
  }



  ///-----------------------------------------dio部分设置-------------------------------------


  void setCookie(String cookie){
    Map<String, dynamic> _headers = new Map();
    _headers["Cookie"] = cookie;
    _dioConfig.headers.addAll(_headers);
  }


  void setHeaders(Map<String, dynamic> headers){
    _dioConfig.headers.addAll(headers);
  }

  void clearHeaders(Map<String, dynamic> headers){
    _dioConfig.headers.clear();
  }

  ///修改默认url
  void changeBaseUrl(String baseUrl){
    _dioConfig.baseUrl = baseUrl;
  }

}



///-----------------------------------------dio自定义配置model-------------------------------------

///Dio的公共配置
class _DioConfig {

  _DioConfig({
    this.baseUrl,
    this.connectTimeout,
    this.receiveTimeout,
    this.pem,
    this.pKCSPath,
    this.pKCSPwd,
    this.codeKey = 'code',
    this.msgKey = 'msg',
    this.dataKey = 'data',
    this.successCode = '0',
    this.responseType,
    this.openLog = true,
    this.retry = 3,
    this.headers,
    this.extra,
    this.contentType,
    this.validateStatus,
    this.followRedirects,
    this.enableCache = true,
    this.enableAutoCookie = false,
    this.interceptors,
  });

  /// 服务器地址
  String baseUrl;

  /// 超时
  int connectTimeout;
  int receiveTimeout;

  /// 详细使用请查看dio官网 https://github.com/flutterchina/dio/blob/flutter/README-ZH.md#Https证书校验.
  /// PEM证书内容.
  String pem;

  /// 详细使用请查看dio官网 https://github.com/flutterchina/dio/blob/flutter/README-ZH.md#Https证书校验.
  /// PKCS12 证书路径.
  String pKCSPath;

  /// 详细使用请查看dio官网 https://github.com/flutterchina/dio/blob/flutter/README-ZH.md#Https证书校验.
  /// PKCS12 证书密码.
  String pKCSPwd;


  /// [int code]字段 key, 默认：code.
  String codeKey = 'code';

  ///[String msg]字段 key 默认：msg.
  String msgKey = 'msg';

  ///[T data]字段 key 默认：data.
  String dataKey = 'data';

  ///服务器成功返回的code
  String successCode = '0';
  String responseType;

  bool openLog = true;

  int retry;

  Map<String, dynamic> headers;
  Map<String, dynamic> extra;
  String contentType;
  ValidateStatus validateStatus;
  bool followRedirects;
  bool enableCache = true;
  bool enableAutoCookie = false;
  List<Interceptor> interceptors;
}



///单个请求配置
class _RequestConfig{
  String method;
  String path;
  bool isFormData = false;
  dynamic data;
  String successCode;
  String codeKey;
  String msgKey;
  String dataKey;
  CancelToken cancelToken;

  _RequestConfig(
      {this.method,
        this.path,
        this.isFormData,
        this.data,
        this.successCode,
        this.codeKey,
        this.msgKey,
        this.dataKey,
        this.cancelToken,
        this.validateHttpData});
}

==> 0.4.17.tar.gz: lib/http/dio_utils.dart <==
import 'dart:convert';
import 'dart:io';
import 'package:dio/adapter.dart';
import 'package:dio/dio.dart';
import 'package:dio_retry_fixed/dio_retry_fixed.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/utils/utils.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';
import 'package:worker_manager/worker_manager.dart';
import 'exception/http_error.dart';
import 'http_data.dart';


Future<HttpData> _request(_DioConfig dioConfig, _RequestConfig requestConfig) async{

  Dio dio = Dio(BaseOptions(
      contentType: Headers.formUrlEncodedContentType,
      connectTimeout: 5 * 1000,
      receiveTimeout: 30 * 1000
  ));

  dio.options = dio.options.copyWith(
      baseUrl: dioConfig.baseUrl??dio.options.baseUrl,
      connectTimeout: dioConfig.connectTimeout??dio.options.connectTimeout,
      receiveTimeout: dioConfig.receiveTimeout??dio.options.receiveTimeout,
      headers: Map.from(dio.options.headers)..addAll(dioConfig.headers??{}),
      responseType: dioConfig.responseType??dio.options.responseType,
      extra: Map.from(dio.options.extra)..addAll(dioConfig.extra??{}),
      contentType: dioConfig.contentType??dio.options.contentType,
      validateStatus: dioConfig.validateStatus??dio.options.validateStatus,
      followRedirects: dioConfig.followRedirects??dio.options.followRedirects
  );


  if (isNotEmpty(dioConfig.interceptors)) {
    dio.interceptors..addAll(dioConfig.interceptors);
  }



  if(dioConfig.openLog && isInDebugMode){
    dio.interceptors.add(PrettyDioLogger(
        requestHeader: true,
        requestBody: true,
        responseBody: true,
        responseHeader: false,
        error: true,
        compact: true,
        maxWidth: 90)
    );
  }


  if (dioConfig.retry != 0) {
    dio.interceptors.add(RetryInterceptor(
        dio: dio,
        options: RetryOptions(
          retries: dioConfig.retry, // Number of retries before a failure
          retryInterval: const Duration(seconds: 1), // Interval between each retry
        )
    ));
  }





  ///-----------------------------------------证书相关信息-------------------------------------
  if (dio != null) {
    (dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
      client.badCertificateCallback = (X509Certificate cert, String host, int port) {
        if (isNotEmpty(dioConfig.pem)) {
          if (cert.pem == dioConfig.pem) {
            // 证书一致，则放行
            return true;
          }else{
            return false;
          }
        }else{
          return true;
        }
      };
    };
    if (isNotEmpty(dioConfig.pKCSPath) && isNotEmpty(dioConfig.pKCSPwd)) {
      (dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate = (HttpClient client) {
        SecurityContext sc = new SecurityContext();
        //file为证书路径
        sc.setTrustedCertificates(dioConfig.pKCSPath, password: dioConfig.pKCSPwd);
        HttpClient httpClient = new HttpClient(context: sc);
        return httpClient;
      };
    }
  }

  Response response;
  String _code;
  String _msg;
  var _resultData;
  HttpData _httpData;

  Options requestOptions = Options();

  if (requestConfig.isFormData) {
    requestConfig.data = FormData.fromMap(requestConfig.data);
  }


  requestOptions.method = requestConfig.method;

  try{
    if (requestConfig.method == Method.get) {
      response = await dio.request(
          requestConfig.path,
          queryParameters: requestConfig.data,
          options:requestOptions,
          cancelToken: requestConfig.cancelToken
      );
    }else{
      response = await dio.request(
          requestConfig.path,
          data: requestConfig.data,
          options: requestOptions,
          cancelToken: requestConfig.cancelToken
      );
    }

    if (isNotEmpty(isNotEmpty(response.data))) {
      if (response.data is List) {
        _resultData = response.data;
        _code = dioConfig.successCode;
      }else{
        Map<String, dynamic> resJson;
        if(response.data is Map){
          resJson = response.data;
        }else{
          resJson = json.decode(response.data);
        }
        _code = resJson[requestConfig.codeKey??dioConfig.codeKey].toString();
        _msg = resJson[requestConfig.msgKey??dioConfig.msgKey];


        if(_code != (requestConfig.successCode??dioConfig.successCode)){
          return HttpData(
            code: _code,
            msg: _msg,
            httpError: HttpError(HttpError.CODE_INCORRECT, _msg)
          );
        }
        _resultData = resJson[requestConfig.dataKey??dioConfig.dataKey];
      }

      _httpData = HttpData(
          code: _code,
          msg: _msg,
          data: _resultData
      );

      return _httpData;
    }else{
      ///response.data为空
      return HttpData(
          code: _code,
          msg: _msg,
          httpError: HttpError(HttpError.PARSE_ERROR, response.statusMessage)
      );
    }
  }catch(e){
    return HttpData(
        code: _code,
        msg: _msg,
        httpError: HttpError(HttpError.UNKNOWN, e.toString())
    );
  }
}


/// 请求方法.
class Method {
  static final String get = "GET";
  static final String post = "POST";
  static final String put = "PUT";
  static final String head = "HEAD";
  static final String delete = "DELETE";
  static final String patch = "PATCH";
}




class DioUtils {

  //服务器路径

  static DioUtils _instance = DioUtils._internal();

  Dio _dio;

  factory DioUtils() => _instance;

  _DioConfig _dioConfig;

  Function _onError;

  Function _onFinish;

  Function _onStart;

  ValidateHttpData _validateHttpData;


  ///-----------------------------------------工具类初始化设置-------------------------------------

  DioUtils._internal();

  ///初始化公共属性
  ///
  /// [baseUrl] 地址前缀
  /// [connectTimeout] 连接超时赶时间
  /// [receiveTimeout] 接收超时赶时间
  /// [interceptors] 基础拦截器
  void init({String baseUrl,
    int connectTimeout,
    int receiveTimeout,
    String pem,
    String pKCSPath,
    String pKCSPwd,
    String codeKey,
    String msgKey,
    String dataKey,
    String successCode,
    String responseType,
    bool openLog = true,
    int retry = 3,
    Map<String, dynamic> headers,
    Map<String, dynamic> extra,
    String contentType,
    ValidateStatus validateStatus,
    bool followRedirects,
    Function onError,
    Function onFinish,
    Function onStart,
    ValidateHttpData validateHttpData,
    bool enableAutoCookie = false,
    List<Interceptor> interceptors}) {

    this._validateHttpData = validateHttpData;
    this._onStart = onStart;
    this._onError = onError;
    this._onFinish = onFinish;

    _dioConfig = _DioConfig(
        baseUrl: baseUrl,
        connectTimeout: connectTimeout,
        receiveTimeout: receiveTimeout,
        pem: pem,
        pKCSPath: pKCSPath,
        pKCSPwd: pKCSPwd,
        codeKey: codeKey??'code',
        msgKey: msgKey??'msg',
        dataKey: dataKey??'data',
        successCode: successCode??'0',
        responseType: responseType,
        openLog: openLog??true,
        retry: retry??3,
        headers: headers??{},
        extra: extra??{},
        contentType: contentType,
        validateStatus: validateStatus,
        followRedirects: followRedirects,
        interceptors: interceptors??[],
    );

  }


  ///-----------------------------------------请求方法封装-------------------------------------

  // ignore: missing_return
  Future<HttpData> request(
      String method,
      String path, {
        String cacheKey,
        bool isFormData = false,
        bool publicMethod = true,
        data,
        Options options,
        CancelToken cancelToken,
        Function onStart,
        Function onError,
        Function onFinish,
        ValidateHttpData validateHttpData,
        String successCode,
        String codeKey,
        String msgKey,
        String dataKey}) async{


    HttpData _httpData;

    bool useFinish = false;

    try{
      if (onStart != null){
        onStart();
      }else if(this._onStart != null){
        if (publicMethod) {
          this._onStart();
        }
      }



      _httpData = await Executor().execute(arg1: _dioConfig, arg2: _RequestConfig(
          method: method,
          path: path,
          isFormData: isFormData,
          data: data,
          successCode: successCode,
          codeKey: codeKey,
          msgKey: msgKey,
          dataKey: dataKey
      ), fun2: _request);



      if (isNotEmpty(validateHttpData)) {
        validateHttpData(_httpData);
      }else if(isNotEmpty(_validateHttpData)){
        _validateHttpData(_httpData);
      }

      if (isNotEmpty(_httpData.httpError)) {
        throw _httpData.httpError;
      }


      if(!useFinish){
        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(this._onFinish != null){
          this._onFinish();
        }
        useFinish = true;
      }

      return _httpData;
    }catch(e){
      var error;
      if (e is DioError) {
        error = HttpError.dioError(e);
      }else{
        error = e;
      }

      if(!useFinish){
        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(this._onFinish != null){
          this._onFinish();
        }
        useFinish = true;
      }


      if(onError != null){
        onError.call(error);
      }else if (this._onError != null) {
        if (publicMethod) {
          this._onError.call(error);
        }
      }

      return Future.error(error);
    }
  }




  void fileUpload(String path, Map<String, dynamic> map, {Function onSendProgress, Function onStart, Function onError, Function onFinish}) async{
    FormData formData = FormData.fromMap(map);
    Response response;
    try{
      response = await _dio.post(
          path,
          data: formData,
          onSendProgress: (int sent, int total){
            if (onSendProgress != null) {
              onSendProgress.call(sent, total);
            }
          }
      );
    }on DioError catch(e){
      throw HttpError.dioError(e);
    }catch(e){
      if (e is HttpError) {
        if(onError != null){
          onError.call(e);
        }else if (this._onError != null) {
          this._onError.call(e);
        }

        if (isNotEmpty(onFinish)) {
          onFinish();
        } else if(this._onFinish != null){
          this._onFinish();
        }
      }
    }
  }



  ///-----------------------------------------dio部分设置-------------------------------------


  void setCookie(String cookie){
    Map<String, dynamic> _headers = new Map();
    _headers["Cookie"] = cookie;
    _dioConfig.headers.addAll(_headers);
  }


  void setHeaders(Map<String, dynamic> headers){
    _dioConfig.headers.addAll(headers);
  }

  void clearHeaders(Map<String, dynamic> headers){
    _dioConfig.headers.clear();
  }

  ///修改默认url
  void changeBaseUrl(String baseUrl){
    _dioConfig.baseUrl = baseUrl;
  }

}



///-----------------------------------------dio自定义配置model-------------------------------------

///Dio的公共配置
class _DioConfig {

  _DioConfig({
    this.baseUrl,
    this.connectTimeout,
    this.receiveTimeout,
    this.pem,
    this.pKCSPath,
    this.pKCSPwd,
    this.codeKey = 'code',
    this.msgKey = 'msg',
    this.dataKey = 'data',
    this.successCode = '0',
    this.responseType,
    this.openLog = true,
    this.retry = 3,
    this.headers,
    this.extra,
    this.contentType,
    this.validateStatus,
    this.followRedirects,
    this.enableCache = true,
    this.interceptors,
  });

  /// 服务器地址
  String baseUrl;

  /// 超时
  int connectTimeout;
  int receiveTimeout;

  /// 详细使用请查看dio官网 https://github.com/flutterchina/dio/blob/flutter/README-ZH.md#Https证书校验.
  /// PEM证书内容.
  String pem;

  /// 详细使用请查看dio官网 https://github.com/flutterchina/dio/blob/flutter/README-ZH.md#Https证书校验.
  /// PKCS12 证书路径.
  String pKCSPath;

  /// 详细使用请查看dio官网 https://github.com/flutterchina/dio/blob/flutter/README-ZH.md#Https证书校验.
  /// PKCS12 证书密码.
  String pKCSPwd;


  /// [int code]字段 key, 默认：code.
  String codeKey = 'code';

  ///[String msg]字段 key 默认：msg.
  String msgKey = 'msg';

  ///[T data]字段 key 默认：data.
  String dataKey = 'data';

  ///服务器成功返回的code
  String successCode = '0';
  String responseType;

  bool openLog = true;

  int retry;

  Map<String, dynamic> headers;
  Map<String, dynamic> extra;
  String contentType;
  ValidateStatus validateStatus;
  bool followRedirects;
  bool enableCache = true;
  List<Interceptor> interceptors;
}



///单个请求配置
class _RequestConfig{
  String method;
  String path;
  bool isFormData = false;
  dynamic data;
  String successCode;
  String codeKey;
  String msgKey;
  String dataKey;
  CancelToken cancelToken;

  _RequestConfig(
      {this.method,
        this.path,
        this.isFormData,
        this.data,
        this.successCode,
        this.codeKey,
        this.msgKey,
        this.dataKey,
        this.cancelToken});
}
